Crate knowledge_base_cli

Crate knowledge_base_cli 

Reusable command-line application support for a file-based knowledge base.

The published binary is the base-only application. Downstream applications can statically register extensions with Application::builder.

Structs

Application
A validated static CLI application.
Builder
Collects the static extensions that form one executable application.
CliError
A CLI error rendered by the application using the base CLI error convention.
ExtensionCommandContext
Context provided to an extension command after optional repository activation.

Enums

BuildError
Errors found while assembling one statically composed application.

Traits

KnowledgeBaseCliExtension
Optional CLI behavior for one statically compiled extension.

Functions

run
Runs the base-only published application.
run_from
Runs the base-only published application with supplied arguments.