pub struct Builder { /* private fields */ }Expand description
Collects the static extensions that form one executable application.
Implementations
Sourceimpl Builder
impl Builder
pub fn new() -> Self
Sourcepub fn with_core_extension<E>(self, extension: E) -> Selfwhere
E: KnowledgeBaseExtension + 'static,
pub fn with_core_extension<E>(self, extension: E) -> Selfwhere
E: KnowledgeBaseExtension + 'static,
Adds an extension that does not expose CLI commands.
Sourcepub fn with_extension<E>(self, extension: E) -> Selfwhere
E: KnowledgeBaseCliExtension + 'static,
pub fn with_extension<E>(self, extension: E) -> Selfwhere
E: KnowledgeBaseCliExtension + 'static,
Adds one extension object with its core contract and CLI capability.
pub fn build(self) -> Result<Application, BuildError>