Reusable command-line application support for a file-based knowledge base.
The published binary is the base-only application. Downstream applications
can statically register extensions with Application::builder.
Structs
- Application
- A validated static CLI application.
- Builder
- Collects the static extensions that form one executable application.
- CliError
- A CLI error rendered by the application using the base CLI error convention.
- Extension
Command Context - Context provided to an extension command after optional repository activation.
Enums
- Build
Error - Errors found while assembling one statically composed application.
Traits
- Knowledge
Base CliExtension - Optional CLI behavior for one statically compiled extension.